procedure li_winbrow
*-- Author: Val Matison
*-- Matison Consulting Group Onc.
*--
*-- Called from the menu while a forms screen is active
*-- Converts a form window into a browse window
*-- Uses the current screen coordinates to create the size of browse window
*-- First step in the process of creating the browse objects
*--

private ln_tr, ;
        ln_tc, ;
        ln_br, ;
        ln_bc
*--
*-- Define the dimensions of the window
*--

ln_tr     = wlrow( lc_window )
ln_tc     = wlcol( lc_window )
ln_br     = ln_tr + wrows( lc_window ) + 1
ln_bc     = ln_tc + wcols( lc_window ) + 1

*-- lc_window has the same name as the primary file in that screen object
*-- It must have a browse name definition within the dictionary so  
*-- it can be browsable

if .not. seek( lc_window, "LI_FLIST" )
 return
endif

release windows &lc_window

do li_bromake with trim( li_flist.browinname ), ;
                   trim( li_flist.broalias ), ;
                   ln_tr, ;
                   ln_tc, ;
                   ln_br, ;
                   ln_bc

*-- Change menu bar prompt to form view so that the view can be changed back to a form
*--
DEFINE BAR 6 OF _record PROMPT "\<Form view"
ON SELECTION BAR 6 OF _record do li_makform

*-- eop li_winbrow


procedure li_bromake
*-- Author: Val Matison
*-- Last update: 08/21/93
*--
*-- Creates a browse window for any open database
*--
*-- Called by the event handler in Core.prg or by
*-- li_winsetup that setups up an initial screen
*--
*-- Send down the title of the browse window
*-- Send down name of the browse alias
*-- gc_brotitl = Title of browse window
*-- lc_bralias = Browse alias
*-- lc_wintitl = Title of FORM that will be used to create browse
*--              or the name of a Window that has just been clicked
*-- 			 Only used when called from a form
*-- ln_tr
*-- ln_tc
*-- ln_br
*-- ln_bc

parameters lc_wintitl, ;
           lc_bralias, ;
           ln_tr, ;
           ln_tc, ;
           ln_br, ;
           ln_bc

*--
*-- If a browse already exists - deactivate it 
*-- Needed for foundation read
*--

if gl_browsin
 do li_broshow
endif

gc_brotitl = alltrim( li_msglist( lc_wintitl ) )

if empty( gc_brotitl )
 gc_brotitl = alias() + " List"
endif

gc_bralias = lc_bralias
gc_wintitl = lc_wintitl
gl_browsin = .t.		&& cancelled in li_broshow

*--
*-- If a browse window does not exist, make a window and browse
*-- Typically this was a form window that was changed to the browse
*-- Window. By defining it here I'm able to create a window that's the 
*-- same size a s the original form window
*-- 

IF NOT WEXIST( lc_wintitl )
 define window (lc_wintitl) from ln_tr, ln_tc to ln_br, ln_bc ;
 system ;
 noclose ;
 float ;
 grow

*-- Insert activation clauses here 
 do broactv with lc_wintitl

 browse window (lc_wintitl) ;
       normal ;
       noappend ;
       nomodify ;
       nodelete ;
       nowait ;
       title (gc_brotitl) 
       
else

 select ( gc_bralias )
 activate window ( lc_wintitl )

*-- Insert activation clauses here 
 do broactv with lc_wintitl
 browse window ( lc_wintitl ) ;
       normal ;
       noappend ;
       nodelete ;
       nomodify ;
       nowait ;
       title ( gc_brotitl )

endif

release windows (lc_wintitl)
do li_tagpop

return


procedure li_broshow
*--
*-- Stops the active browse and displays image to window
*-- Called from setup routine in any form based program
*-- 
private lc_brotitl, ;
        lc_wintitl, ;
        ln_tc, ;
        ln_tr, ;
        ln_bc, ;
        ln_br

lc_brotitl = gc_brotitl
lc_wintitl = gc_wintitl
gl_browsin = .f.	&& set in li_bromake

*-- The next if block checks to see if the browse was closed manually
if .not. wexist( gc_brotitl )
 return
endif

ln_tr      = wlrow( lc_brotitl )
ln_tc      = wlcol( lc_brotitl )
ln_bc      = ln_tc + wcols( lc_brotitl ) - 1
ln_br      = ln_tr + wrows( lc_brotitl ) - 1

define window (lc_wintitl) ;
       from ln_tr, ln_tc to ln_br, ln_bc ;
       noclose ;
       float ;
       grow ;
       zoom ;
       none

activate window (lc_brotitl) in window (lc_wintitl) bottom
move window (lc_brotitl) to 0,0
activate window (lc_wintitl) bottom
show window (lc_brotitl) in window (lc_wintitl) save bottom
release windows (lc_brotitl)

*-- Insert deactivation clauses here 
*--
 do brelease with lc_wintitl

return

* eop build.prg



procedure li_makform
*--
*-- Make form from an active browse
*-- Used in conjunction with li_winbrow
*-- 
*-- Last update: 05/02/93
*-- Original Author: Val Matison
*--
private lc_dbf, ;
        lc_proc

lc_dbf = alias()

if .not. seek( lc_dbf, "LI_FLIST" )
 return
else
 lc_proc = alltrim( li_flist.mainscreen ) + ".SPR"
endif

gl_browsin = .f.	&& set in li_bromake

*-- The next if block checks to see if the browse was closed manually
if .not. wexist( gc_brotitl )
 return
endif

release windows ( gc_brotitl )
DEFINE BAR 6 OF _record PROMPT "\<Table view"
ON SELECTION BAR 6 OF _record do li_winbrow

do ( lc_proc )

*-- eop 





procedure li_yesno
*-- Modified: 12/15/92

PARAMETERS lc_message,ll_yes
private ln_choice

if parameters()=1	&& default to false
 ll_yes=.f.
endif

ln_choice = iif( ll_yes, 1, 2 )

if gl_beep
 ?? chr(7)
endif

IF NOT WEXIST("yesno")
	DEFINE WINDOW yesno ;
		FROM INT((SROW()-7)/2),INT((SCOL()-75)/2) ;
		TO INT((SROW()-7)/2)+6,INT((SCOL()-75)/2)+74 ;
		FLOAT ;
		NOCLOSE ;
		SHADOW ;
		DOUBLE ;
		COLOR SCHEME 7
ENDIF

IF WVISIBLE("yesno")
	ACTIVATE WINDOW yesno SAME
ELSE
	ACTIVATE WINDOW yesno NOSHOW
ENDIF

@ 1,3 SAY lc_message ;
	SIZE 1,68
@ 3,28 GET ln_choice ;
	PICTURE "@*HT \!\<Ok;\?\<Cancel" ;
	SIZE 1,8,1 ;
	DEFAULT 1

IF NOT WVISIBLE("yesno")
	ACTIVATE WINDOW yesno
ENDIF

READ CYCLE MODAL object ln_choice

RELEASE WINDOW yesno

#REGION 1
return iif(ln_choice=1, .t., .f. )


procedure li_begmon	&& returns first of month given a date
parameter ld_date
return ld_date-day(ld_date)+1
* eop li_begmon


procedure li_movemsg
*--
*-- Last update: 08/15/93
*--
private ln_obj
ln_obj = OBJNUM( ln_positn )

Do case
 case _CUROBJ = ln_obj 
  return li_msglist("GOFIRST")

 case _CUROBJ = ln_obj + 1 
  return li_msglist("GONEXT")

 case _CUROBJ = ln_obj + 2
  return li_msglist("GOPREVIOUS")

 case _CUROBJ = ln_obj + 3
  return li_msglist("GOBOTTOM")

 case _CUROBJ = ln_obj + 4
  return li_msglist("SCREXIT")

 case _CUROBJ = ln_obj + 4
  return li_msglist("PRESSTOBRO")

 otherwise
  return ""
endcase


procedure li_waitmsg
*-- Produces a wait message with bell optional
*-- If three parameters use the message sent down in the third parameter
*-- otherwise use "lc_msgkey" to get the message from an open file
*--
*-- Last update: 07/03/23
*--
*--
*-- lc_msgkey is the indexed variable used to find the message
*-- ll_bell tells me to ring the bell or not
*-- ll_wait if true sends string to wait window; false to return the string
*-- lc_message is a string sent down to this program
*-- ln_timeout tells how long to keep msg; 0 means all the time time
*-- lc_warning specifies the colour of the wait message; 
*-- 	"R" Means Red; used for critical areas
*--		"Y" means Yellow; general warnings
*--		"G" or nothing/blank is for general messages that just notify the user

parameters lc_msgkey, ;
           ll_bell, ;
           ll_wait, ;
           lc_message, ;
           ln_timeout, ;
           lc_warning

private lc_waitmsg, ;
        lc_schem5

lc_waitmsg = ""

if empty( lc_message )
 lc_waitmsg  = li_msglist( lc_msgkey )
else
 lc_waitmsg  = lc_message
endif

if ll_bell
 ?? chr(7)
endif

if empty( lc_warning )
 lc_warning = " "
endif

if ll_wait
*-- New stuff
 lc_schem5 = scheme(5)

 do case

  case lc_warning = "R"
  SET COLOR OF SCHEME 5 TO W+/R,w+/r,w+/r

  case lc_warning = "Y"
*  SET COLOR OF SCHEME 5 TO gr+/n, w/gr+, w/gr+
  SET COLOR OF SCHEME 5 TO gr+/n, gr+/n, gr+/n

 endcase
*-- End of new stuff

 if empty( ln_timeout )
  wait lc_waitmsg window nowait

 else
  wait lc_waitmsg window timeout ln_timeout

 endif

*-- New stuff
 SET COLOR OF SCHEME 5 TO ( lc_schem5 )
*-- End of new stuff

else
 return lc_waitmsg

endif

* eop lc_waitmsg


procedure li_msglist
*-- Procedure returns a message string from an open file
*--
*-- Last update 03/06/93
*--
*-- I don't want to clutter up my program files with a bunch of messages
*-- Just send down the name and the procedure will look it up
*-- and return the string
*-- It is assumed that the message file is always open and that the 
*-- tag is set to the message key field
*-- A blank is returned if nothing found.
*--
parameters lc_msgname
private ll_found
*ll_found = seek(lc_msgname, "LI_MSG" )
if seek(lc_msgname, "LI_MSG" )
 return trim( li_msg.message )
else
 return ""
endif



procedure li_tagpop
*--
*-- Last update: 03/31/93
*--
*-- Creates a popup and bar for every active tag in a file
*--

private ln_k, ;
        ln_barcnt, ;
        ln_tag, ;
        ln_sys21, ;
        lc_alias

external array ga_tagname

ln_tag    = 0
ln_k      = 1
ln_barcnt = 1
ln_sys21  = val( sys( 21 ) )
lc_alias  = alias()

*-- Create the order popup for every tag in this master file
if .not. empty( tag( 1 ) )

DEFINE POPUP lp_order MARGIN RELATIVE SHADOW COLOR SCHEME 4

do while .not. empty(tag(ln_k))
 if upper( trim( tag( ln_k ) ) ) <> "DELETED"

  define bar ln_barcnt of lp_order prompt li_msglist( lc_alias+tag( ln_k ) )
  ga_tagname[ ln_barcnt ] = tag( ln_k )

*  define bar ln_barcnt of lp_order prompt tag( ln_k )
  ln_barcnt = ln_barcnt + 1

 else
  ln_tag = ln_k

 endif
 ln_k = ln_k + 1
enddo

on bar 5 OF _record activate popup lp_order
on selection popup lp_order do li_setord with prompt(), bar()
*-- sys(21) returns current tag in use so this will mark the bar

*-- Mark the popup

if ln_tag = 1									&& If first tag is deleted
 set mark of bar ln_sys21 - 1 of lp_order .t.	&& Shift back one since I won't have a delted bar
else
 set mark of bar ln_sys21 of lp_order .t.	&& mark first bar since probably  used
endif

endif

if .not. gl_browsin 
 DEFINE BAR 6 OF _record PROMPT "\<Table view"
 ON SELECTION BAR 6 OF _record do li_winbrow
else
 DEFINE BAR 6 OF _record PROMPT "\<Form view"
 ON SELECTION BAR 6 OF _record do li_makform
endif

return
* eop li_tagpop


procedure li_setord
*--
*-- Last update: 07/11/93
*-- 
*-- Selection routine for li_tagpop
*-- Sets order and seek messages for any screen
*-- ln_bar contains a refernece to the tag number
*-- 
*-- Note:  The table must be open and selected for this to work properly
*--
parameters lc_bar, ln_bar

external array ga_tagname

if seek( alias() + ga_tagname[ ln_bar ] , "LI_FLIST" )

*if seek( alias() + lc_bar, "LI_FLIST" )
 gc_key       = LI_FLIST.key
 gc_fldname   = LI_FLIST.fldname
 gc_seekmsg   = LI_FLIST.seekmsg

endif

 set order to tag ( ga_tagname[ ln_bar ] )

* set order to tag ( lc_bar )
 set mark of popup lp_order .f.		&& turn all off
 set mark of bar ln_bar of lp_order .t.	&& now mark just one

*--
*-- Note that the browse window name musn't be:
*-- "< Inventory Location >" but should be:
*-- "Inventory Location"
*--

if gl_browsin
 lc_top = wontop()
 show window ( wontop() ) refresh
endif

return


procedure li_add				&& add info to screen
*--
*-- Last update: 08/16/93
*--
parameters lc_action, ;
           ln_obj	&& send down add, edit, exis and object
private lc_scheme1
lc_scheme1 = scheme(1)

if gl_browsin
 do li_waitmsg with "FORMONLY", .t., .t.
 return
endif
 

 gl_editing = .t.				&& Both gl_adding and gl_editing are swithced to normal in the validation claus of the OK/Cancel button
 _curobj    = 1

 do case

  case lc_action = "ADD"
   gl_adding  = .t.
   scatter memvar blank
   set color of scheme(1) to ( gc_nocolor )				&& Allows say fields in read show to come out blank
   show gets window ( lc_window ) color ( gc_getcolr )	&& Shows active gets in different color
   set color of scheme 1 to ( lc_scheme1 )

  case lc_action = "EDIT"
   scatter memvar
   show gets only window ( lc_window ) color ( gc_getcolr )

  case lc_action = "EXIS"	&& Edit existing memory variables
   _curobj    = ln_obj
   gl_adding  = .t.			&& THESE TWO VARIABLES SHOULD BE FLAGGED SOMEHOW

 endcase

*-- Where is gn_recno used ????????????????
gn_recno=recno()
show get ln_positn  disable

show get ln_action,1  enable
show get ln_action,2  enable

endif

clear typeahead
return


procedure li_okcanc
*--
*-- OK/ Cancel termination during Add/Edit cycle of read
*-- Last update: 04/26/93
*-- 

parameters ln_action

private lc_choice, ;
        lc_dbf

lc_choice = substr( "OCD", ln_action, 1 )
lc_dbf    = alias()

do case
 case lc_choice = "O"			&& OK Pressed in screen push button
  if li_yesno( li_msglist( "ASKTOSAVE" ), .f. )

   if gl_adding
    insert into ( lc_dbf ) from memvar
   else
    gather memvar
   endif

  else
   scatter memvar
  endif

  show gets window ( lc_window ) color ( gc_saycolr )

 case lc_choice = "C"			&& Cancel pressed

  if .not. gl_browsin
   go gn_recno
   scatter memvar
   show gets window ( lc_window ) color ( gc_saycolr )
  endif

*-- I have to get the escape character out of the keyboard buffer or 
*-- else a screen will be released since an ESCAPE is sitting in the
*-- buffer

endcase

unlock		&& I'm assuming that I'm unlocking one record in the current table

show get ln_positn enable 
show get ln_action disable

gl_adding  = .f.	&& set in rec_add or rec_edit
gl_editing = .f.	&& set in rec_add or rec_edit

*--
*-- Set the first button as default
*-- 

_curobj = objnum( ln_positn )
return .t.


procedure li_delete
*--
*-- Prompts user for record deletion
*-- Yes means go to processing routine to delete
*--
*-- Last update: 07/18/93
*--

if li_yesno( li_msglist( "ASKTODELE" ), .t. )
  delete 
  skip

  if eof()
    go bottom
  endif

  if .not. gl_browsin
   scatter memvar
   show gets window ( lc_window )
  endif

 return .t.
else
 return .f.
endif
*-- eop li_delete



procedure li_fldpop
*-- Global foreign key validation procedure
*-- Parameters to send down are: 
*-- lu_value  = item you are seeking
*-- lc_table  = file to seek in
*-- lc_window = name of calling window; I know if closed during validation
*-- lc_msgkey = Reference in message table for title of popup
*-- ll_seek   = False will force the popup - Used by Seekitem.spr
*-- lc_key    = Foreign key that will be loaded into the current variable
*-- lc_fld1, lc_fld2 = additional field names used in prompt
*-- lc_footer = Footer of popup
*--
*--
*-- Last update: 08/13/93
*--
*--

parameters lu_value, ;
           lc_table, ;
           lc_window, ;
           lc_msgkey, ;
           ll_seek, ;
           lc_key, ;
           lc_fld1, ;
           lc_fld2

private ln_popwid, ;
        lc_sep, ;
        lc_alias, ;
        ln_params, ;
        ln_reccoun, ;
        ln_row, ;
        ln_col, ;
        lc_title, ;
        ll_found

ln_params = parameters()	&& minimum count is 6 more means lc_fld* has data
lc_sep    = chr(179)
lc_alias  = alias()
ln_row    = row()
ln_col    = col()
ll_found  = .f.

if .not. wvisible(lc_window)	&& window closed get out of the validation
 return .t.						&& read terminated in deactivate validation 
endif

select ( lc_table )

ll_found = seek( lu_value )

if ll_seek .and. ll_found
 select ( lc_alias )
 return .t.
else
 if eof()	&& If near is on, pointer will be close to location in file
  go top
 endif
endif 

*-- Accomodate numeric keys
if type( (lc_key) ) = "N"
 lc_uniqfld = str( eval( lc_key ))
else
 lc_uniqfld = eval(lc_key)
endif

ln_popwid  = len( lc_uniqfld + lc_sep ) + len( eval( lc_fld1 ) )
ln_row     = row()
ln_col     = col() + 4
ln_reccoun = reccoun()

push key clear
set confirm on

lc_title = li_msglist(lc_msgkey)	&& gets message from message file

if type( (lc_key) ) = "N"

define popup lp_pop ;
       from ln_row, ln_col ;
       TO ln_row + 1 + min( ln_reccoun, 20 ), ln_col + ln_popwid ;
       title lc_title ;
       in screen ;
       prompt field str( &lc_key ) + lc_sep + &lc_fld1
else

define popup lp_pop ;
       from ln_row, ln_col ;
       TO ln_row + 1 + min( ln_reccoun, 20 ), ln_col + ln_popwid ;
       title lc_title ;
       in screen ;
       prompt field &lc_key + lc_sep + &lc_fld1

endif

on selection popup lp_pop deactivate popup lp_pop
activate popup lp_pop rest
pop key

lu_value = eval( lc_key )
release popups lp_pop

set confirm off
select ( lc_alias )
return .t.
*-- eop 

procedure li_movewin
*-- Moves window just below and to the right of the previous window
*-- Called by all screens initially
*-- This module is NO GOOD for multiple window reads
*--
*-- Last update: 07/30/93
*-- 
*-- lc_window = Name of current window to move
*-- 
*--

parameters lc_window
*--
*-- Last update: 08/15/93
*--
private lc_wlast
lc_wlast = wontop()

if !empty( lc_wlast ) .and. lc_wlast <> "GW_MESSAGE"	&& if screen not last window
 move window &lc_window to wlrow(lc_wlast) + 1, wlcol(lc_wlast) + 2
else
 move window &lc_window to 1, 0		&& first on screen put in corner
endif


procedure li_moverec
*-- Moves record pointer and displays that record
*-- Last update: 07/24/93
*--
*--
parameters ln_positn
private lc_pos
lc_pos=substr( "FPNLE",ln_positn )

do case	
 case lc_pos = 'F'		&& First Record
 GO TOP	

 case lc_pos = 'N'		&& Next Record
 if eof()
   go bottom

  else
   SKIP 1

  IF EOF()
   GO BOTTOM
   do li_waitmsg with "EOF", gl_beep, .t., "", 2, "Y"
  ENDIF

 endif

 case lc_pos = 'P'		&& Previous

 SKIP -1
 IF BOF()
  GO TOP
  do li_waitmsg with "BOF", gl_beep, .t., "", 2, "Y"
 endif

 case lc_pos = 'L'		&& Bottom
  go bottom

 case lc_pos = 'E'		&& Exit screen
  deactivate window ( lc_window )

endcase

if lc_pos <> "E"		&& Don't do show gets on exit since window will get opened
*-- check to see if I want to use memo
 scatter memvar memo
 _curobj=_curobj
 SHOW GETS
endif


procedure li_wisetup
*-- Global window setup routine
*-- last update: 08/15/93
*--
*-- All global variables defined in core.prg

parameters lc_window, ;
           lc_proc, ;
           lc_key, ;
           lc_fldname, ;
           lc_seekmsg

gn_close   = gn_close + 1
gc_proc    = lc_proc
gc_key     = lc_key
gc_fldname = lc_fldname
gc_seekmsg = lc_seekmsg

*-- Deactivate current browse screen
if gl_browsin
 do li_broshow						
endif

if .NOT. wvisible( lc_window ) .and. wexist( lc_window )		&& first time into procedure
 do li_waitmsg with "SCRSETUP", .f., .t.
 do li_movewin with lc_window		&& open window at corner of previous
endif

do li_tagpop						&& Create all popups for this screen

*-- eop li_wisetup



procedure li_wiclose
*-- Called from read deactivate
*--
*-- Last update: 05/03/93
*--
parameters lc_close
gl_adding  = .f.
gl_editing = .f.
*show get ln_positn disable
return .t.


procedure li_reclose
*-- Read Close Routine
*-- Cleanup Called from read exit 
*-- Activated when current windo is on top and another window
*-- is activated with a mouse click
*-- Last update: 08/15/93

private lc_key
lc_key     = lastkey()
gn_close   = gn_close - 1
gl_oktoadd = .t.
gl_hdline  = .f.		&& Allow table view to be active again
gl_adding  = .f.
gl_editing = .f.

if lc_key = gk_esckey .or. .not. wvisible( lc_window )	
  release window ( lc_window )
endif

* if gl_editing			&& Edited out for now but reintroduce later
* do li_savesta
* do li_okcanc with 3
* endif

*-- Only release if the window has not been changed to a browse
*-- and seekwindow or any other not activated

if .not. gl_browsin
 release popups lp_order
endif

*--
*-- eop 




procedure li_opendbf
*-- Closes all files first
*-- Global procedure to open all files listed in li_flist
*-- Last update: 08/06/93
*--
private la_dbflist
close databases

select dbfname, ;
       tagname, ;
       mastertag, ;
       descrip ;
  from li_flist ;
 where ( alwaysopen .and. mastertag ) ;
 order by 1,3 ;
 into array la_dbflist

use

*--
*-- I want to keep li_flist open so I use ln_k+1 to move the area
*-- that files are opened in.
*--
for ln_k = 1 to alen( la_dbflist,1 )
 do li_waitmsg with " ", .f., .t., "Opening file: " + alltrim(la_dbflist[ ln_k,4 ]), 0, "R"
 use la_dbflist[ ln_k,1 ] in (ln_k) order tag la_dbflist[ ln_k,2 ]
endfor

wait clear
do li_waitmsg with "FILESOPEN", .f., .t., "", 2

return


procedure li_reset
*--
*-- Last update: 06/27/93
*--

private lc_col, ;
        la_dbflist

lc_col=19

if li_yesno( li_msglist( "ASKTOINDEX" ), .f.)
 close databases
 set exclusive on

 select distinct dbfname ;
   from li_flist ;
   into cursor lq_flist 

 select dbfname, ;
        expr, ;
        tagname ;
   from li_flist ;
  where .not. empty( expr ) ;
  order by 1, 2 ;
   into cursor lq_dbflist 

 select li_flist
 use

*select distinct dbfname ;
*  from li_flist ;
*  into cursor lq_flist 

*select dbfname, ;
*       expr, ;
*       tagname ;
*  from li_flist ;
* where .not. empty( expr ) ;
* order by 1, 2 ;
*  into cursor lq_dbflist 

*select li_flist
*use

 define window lw_display from 1,1 to 10,78 shadow title "File Maintenance"
 activate window lw_display

 @ 2,2 say "Current file:"
 @ 3,7 say      "Process:"

 select lq_flist

 scan
 lc_dbf = lq_flist.dbfname

 select expr, ;
        tagname ;
   from lq_dbflist ;
  where lq_dbflist.dbfname = lc_dbf ;
   into array la_dbflist 

 select 0
 use ( lc_dbf )
 delete tag all

 for ln_k = 1 to alen( la_dbflist,1 )
  @ 2,lc_col say space(30)
  @ 2,lc_col say lc_dbf
  @ 3,lc_col say la_dbflist[ ln_k, 2 ]
  lc_exp = rtrim( la_dbflist[ ln_k, 1 ] ) + " TAG " + la_dbflist[ ln_k, 2 ]
  index on &lc_exp
 endfor

 use
 select lq_flist

endscan


close databases
release windows lw_display

*-- reopen files before returning to main program

set exclusive off
do li_opendbf

endif
return
*-- eop li_reset


procedure li_setco
*-- Li_setcol
*--
*-- Allows user to select colour
*-- Last update: 03/31/93
*--
private ln_keypres, lc_color
ln_keypres = 0
lc_color = ""

set resource off
select name ;
       from li_stat ;
 where id="COLORSET" ;
  into cursor lq_color ;
 order by 1

use in li_stat
set resource to "LI_STAT"
set resource on

define popup lp_setcol ;
       in screen ;
       footer "Enter or Mouse" ;
       prompt field name ; 
       scroll ;
       title "Color Sets"

on selection popup lp_setcol deactivate popup lp_setcol
activate popup lp_setcol

ln_keypres=lastkey()

if ln_keypres = gk_enter
 lc_color = trim( lq_color.name )
 set color set to ( trim( lc_color ) )
 do mainmenu.mpr
endif

return

*-- EOP LI_SETCO.PRG